[svn-commits] mmichelson: branch group/CCSS r227052 - /team/group/CCSS/main/ccss.c

SVN commits to the Digium repositories svn-commits at lists.digium.com
Mon Nov 2 17:08:38 CST 2009


Author: mmichelson
Date: Mon Nov  2 17:08:34 2009
New Revision: 227052

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=227052
Log:
Change "done" to "ignore" in datastores since it makes more sense.


Modified:
    team/group/CCSS/main/ccss.c

Modified: team/group/CCSS/main/ccss.c
URL: http://svnview.digium.com/svn/asterisk/team/group/CCSS/main/ccss.c?view=diff&rev=227052&r1=227051&r2=227052
==============================================================================
--- team/group/CCSS/main/ccss.c (original)
+++ team/group/CCSS/main/ccss.c Mon Nov  2 17:08:34 2009
@@ -1279,7 +1279,7 @@
 	 * already exists on the channel, we can determine if we
 	 * should be adding any new interface information to tree.
 	 */
-	char done;
+	char ignore;
 	/*!
 	 * When we process a CC control frame, we will create a new instance
 	 * of the CC core for the call. However, we only need to do this on 
@@ -1347,7 +1347,7 @@
 	if (!new_cc_interfaces) {
 		return NULL;
 	}
-	new_cc_interfaces->done = old_cc_interfaces->done;
+	new_cc_interfaces->ignore = old_cc_interfaces->ignore;
 	new_cc_interfaces->dial_parent_id = old_cc_interfaces->dial_parent_id;
 	new_cc_interfaces->cc_is_offerable = 0;
 	ao2_t_ref(old_cc_interfaces->interface_tree, +1, "New ref due to duplication of interface tree");
@@ -1591,14 +1591,14 @@
 
 	cc_interfaces = cc_datastore->data;
 
-	if (cc_interfaces->done) {
+	if (cc_interfaces->ignore) {
 		ast_channel_unlock(inbound);
 		return;
 	}
 
 	if (!(core_instance = find_cc_core_instance(cc_interfaces->core_id)) &&
 			!(core_instance = cc_core_init_instance(inbound, cc_interfaces->interface_tree, cc_interfaces->core_id))) {
-		cc_interfaces->done = 1;
+		cc_interfaces->ignore = 1;
 		ast_channel_unlock(inbound);
 		return;
 	}
@@ -1653,13 +1653,13 @@
 	 * been called. We need to create/initialize the datastore.
 	 *
 	 * 2. The channel does have a cc_interface datastore on it and
 	 * the "done" indicator is 0. This means that a Local channel
 	 * was called by a "parent" dial. We can check the datastore's
 	 * parent field to see who the root of this particular dial tree
 	 * is.
 	 *
 	 * 3. The channel does have a cc_interface datastore on it and
 	 * the "done" indicator is 1. This means that a second Dial call
 	 * is being made from an extension. In this case, we do not
 	 * want to make any additions/modifications to the datastore. We
 	 * will instead set a flag to indicate that CCSS is completely
@@ -1687,10 +1687,10 @@
 	ast_channel_unlock(chan);
 
 	interfaces = cc_interfaces_datastore->data;
-	if (interfaces->done) {
+	if (interfaces->ignore) {
 		/* Situation 3 has occurred */
 		*ignore_cc = 1;
-		ast_log_dynamic_level(cc_logger_level, "Datastore is present with done flag set. Ignoring CC offers on this call\n");
+		ast_log_dynamic_level(cc_logger_level, "Datastore is present with ignore flag set. Ignoring CC offers on this call\n");
 		return 0;
 	}
 
@@ -2569,7 +2569,7 @@
 
 struct cc_recall_ds_data {
 	int core_id;
-	char done;
+	char ignore;
 	char nested;
 	struct ast_cc_interface_tree *interface_tree;
 };
@@ -2656,7 +2656,7 @@
 
 	recall_data = recall_datastore->data;
 
-	if (recall_data->done) {
+	if (recall_data->ignore) {
 		/* Though this is a recall, the call to this particular interface is not part of the
 		 * recall either because this is a call forward or because this is not the first
 		 * invocation of Dial during this call
@@ -2774,12 +2774,12 @@
 	ast_channel_lock(chan);
 	if ((cc_datastore = ast_channel_datastore_find(chan, &dialed_cc_interfaces_info, NULL))) {
 		cc_interfaces = cc_datastore->data;
-		cc_interfaces->done = 1;
+		cc_interfaces->ignore = 1;
 	}
 
 	if ((cc_recall_datastore = ast_channel_datastore_find(chan, &recall_ds_info, NULL))) {
 		recall_cc_data = cc_recall_datastore->data;
-		recall_cc_data->done = 1;
+		recall_cc_data->ignore = 1;
 	}
 	ast_channel_unlock(chan);
 }
@@ -2852,7 +2852,7 @@
 		return -1;
 	}
 	recall_data = recall_datastore->data;
-	if (recall_data->nested || recall_data->done) {
+	if (recall_data->nested || recall_data->ignore) {
 		/* If this is being called from a nested Dial, it is too
 		 * early to determine if the recall has actually completed.
 		 * The outermost dial is the only one with the authority to
@@ -1653,13 +1653,13 @@
 	 *
 	 * 2. The channel does have a cc_interface datastore on it and
-	 * the "done" indicator is 0. This means that a Local channel
+	 * the "ignore" indicator is 0. This means that a Local channel
 	 * was called by a "parent" dial. We can check the datastore's
 	 * parent field to see who the root of this particular dial tree
@@ -1653,13 +1653,13 @@
 	 *
 	 * 3. The channel does have a cc_interface datastore on it and
-	 * the "done" indicator is 1. This means that a second Dial call
+	 * the "ignore" indicator is 1. This means that a second Dial call
 	 * is being made from an extension. In this case, we do not
 	 * want to make any additions/modifications to the datastore. We




More information about the svn-commits mailing list